Execution engine for Workflow Description Language (WDL) documents.
Modules
- config
- Implementation of engine configuration.
- diagnostics
- Implementation of evaluation diagnostics.
- path
- Representation of evaluation paths that support URLs.
- trie
- Implementation of the inputs prefix trie.
- v1
- Implementation of evaluation for V1 documents.
Structs
- Apptainer
Config - Configuration for the Apptainer container runtime.
- Apptainer
State - The state of an Apptainer backend for a given top-level execution.
- Array
- Represents an
Arrayvalue. - Call
Location - Represents the location of a call in an evaluation error.
- Call
Value - Represents the outputs of a call.
- Cancellation
Context - Represents context for cancelling workflow or task evaluation.
- Compound
Value Serializer - Serializes a
CompoundValuewith optional serialization of pairs. - Docker
Backend - Represents the Docker backend.
- Evaluated
Task - Represents an evaluated task.
- Events
- Represents events that may be sent during WDL evaluation.
- Guest
Path - Represents a path to a file or directory on the guest.
- Hints
Value - Represents a hints value from a WDL 1.2 hints section.
- Host
Path - Represents a path to a file or directory on the host file system or a URL to a remote file.
- Input
- Represents a
FileorDirectoryinput to a task. - Input
Value - Represents an input value from a WDL 1.2 hints section.
- Local
Backend - Represents a task execution backend that locally executes tasks.
- Located
Json Value - An input value that has not yet had its paths normalized and been converted to an engine value.
- LsfApptainer
Backend - The experimental LSF + Apptainer backend.
- LsfApptainer
Backend Config - Configuration for the LSF + Apptainer backend.
- LsfQueue
Config - Configuration for an LSF queue.
- Map
- Represents a
Mapvalue. - Object
- Represents an
Objectvalue. - Output
Value - Represents an output value from a WDL 1.2 hints section.
- Outputs
- Represents outputs of a WDL workflow or task.
- Pair
- Represents a
Pairvalue. - Previous
Task Data Value - Represents a
task.previousvalue containing data from a previous attempt. - Scope
- Represents an evaluation scope in a WDL document.
- Scope
Index - Represents an index of a scope in a collection of scopes.
- Scope
Ref - Represents a reference to a scope.
- Slurm
Apptainer Backend - The experimental Slurm + Apptainer backend.
- Slurm
Apptainer Backend Config - Configuration for the Slurm + Apptainer backend.
- Slurm
Partition Config - Configuration for a Slurm partition.
- Source
Error - Represents an error that originates from WDL source.
- Struct
- Represents a
Structvalue. - Task
Execution Constraints - Represents constraints applied to a task’s execution.
- Task
Execution Result - Represents the result of a task’s execution.
- Task
Inputs - Represents inputs to a task.
- Task
Post Evaluation Data - Immutable data for task values after requirements evaluation (WDL 1.2+).
- Task
Post Evaluation Value - Represents a
taskvariable value after requirements evaluation (WDL 1.2+). - Task
PreEvaluation Value - Represents a
taskvariable value before requirements evaluation (WDL 1.3+). - Task
Spawn Info - Represents information for spawning a task.
- Task
Spawn Request - Represents a request to spawn a task.
- TesBackend
- Represents the Task Execution Service (TES) backend.
- Value
Serializer - Serializes a value with optional serialization of pairs.
- Workflow
Inputs - Represents inputs to a workflow.
Enums
- Cancellation
Context State - Represents the current state of a
CancellationContext. - Compound
Value - Represents a compound value.
- Content
Kind - Gets the kind of content.
- Engine
Event - Represents an event from the WDL evaluation engine.
- Evaluation
Error - Represents an error that may occur when evaluating a workflow or task.
- Hidden
Value - Represents a hidden value.
- Inputs
- Represents inputs to a WDL workflow or task.
- Primitive
Value - Represents a primitive WDL value.
- Storage
Unit - Represents a storage unit.
- Value
- Represents a WDL runtime value.
Traits
- Coercible
- Implemented on coercible values.
- Evaluation
Context - Represents context to an expression evaluator.
- Task
Execution Backend - Represents a task execution backend.
Functions
- convert_
unit_ string - Converts a unit string (e.g.
2 GiB) to bytes.
Type Aliases
- Evaluation
Result - Represents a result from evaluating a workflow or task.
- JsonMap
- A type alias to a JSON map (object).