pub enum BackendConfig {
Local {
config: LocalBackendConfig,
},
Docker {
config: DockerBackendConfig,
},
Tes {
config: TesBackendConfig,
},
LsfApptainer {
config: LsfApptainerBackendConfig,
},
SlurmApptainer {
config: SlurmApptainerBackendConfig,
},
}Expand description
Represents supported task execution backends.
Variants
Local
Use the local task execution backend.
Fields
config: LocalBackendConfigThe inner local backend configuration.
Docker
Use the Docker task execution backend.
Fields
config: DockerBackendConfigThe inner Docker backend configuration.
Tes
Use the TES task execution backend.
Fields
config: TesBackendConfigThe inner TES backend configuration.
LsfApptainer
Use the experimental LSF + Apptainer task execution backend.
Requires enabling experimental features.
Fields
config: LsfApptainerBackendConfigThe inner LSF Apptainer backend configuration.
SlurmApptainer
Use the experimental Slurm + Apptainer task execution backend.
Requires enabling experimental features.
Fields
config: SlurmApptainerBackendConfigThe inner Slurm Apptainer backend configuration.
Implementations
Sourceimpl BackendConfig
impl BackendConfig
Sourcepub fn as_local(&self) -> Option<&LocalBackendConfig>
pub fn as_local(&self) -> Option<&LocalBackendConfig>
Converts the backend configuration into a local backend configuration
Returns None if the backend configuration is not local.
Sourcepub fn as_docker(&self) -> Option<&DockerBackendConfig>
pub fn as_docker(&self) -> Option<&DockerBackendConfig>
Converts the backend configuration into a Docker backend configuration
Returns None if the backend configuration is not Docker.
Sourcepub fn as_tes(&self) -> Option<&TesBackendConfig>
pub fn as_tes(&self) -> Option<&TesBackendConfig>
Converts the backend configuration into a TES backend configuration
Returns None if the backend configuration is not TES.
Sourcepub fn as_lsf_apptainer(&self) -> Option<&LsfApptainerBackendConfig>
pub fn as_lsf_apptainer(&self) -> Option<&LsfApptainerBackendConfig>
Converts the backend configuration into a LSF Apptainer backend configuration
Returns None if the backend configuration is not LSF Apptainer.
Sourcepub fn as_slurm_apptainer(&self) -> Option<&SlurmApptainerBackendConfig>
pub fn as_slurm_apptainer(&self) -> Option<&SlurmApptainerBackendConfig>
Converts the backend configuration into a Slurm Apptainer backend configuration
Returns None if the backend configuration is not Slurm Apptainer.