pub enum BuilderError {
Io {
path: PathBuf,
error: Error,
},
Parse {
path: Option<PathBuf>,
source: String,
error: Error,
},
Deserialize {
path: Option<PathBuf>,
source: String,
error: FromTomlError,
},
Merge(BuilderMergeError),
}Expand description
Represents an error encountered while building a configuration.
Variants
Io
Failed to read the provided configuration file.
Parse
Failed to parse the provided configuration file.
Fields
Deserialize
Failed to deserialize the provided configuration file.
Fields
error: FromTomlErrorThe error that was encountered.
Merge(BuilderMergeError)
Failed to merge configuration.
Implementations
Sourceimpl BuilderError
impl BuilderError
Sourcepub fn path(&self) -> impl Display + Clone
pub fn path(&self) -> impl Display + Clone
Gets the path associated with the error.
If the error relates to parsing or deserializing an in-memory string,
the path will be <string>.
If the error relates to parsing or deserializing the merged
configuration, the path will be <merged>.
Sourcepub fn toml_error(&self) -> Option<&Error>
pub fn toml_error(&self) -> Option<&Error>
Gets the TOML error associated with the error.
Returns None if the error is not associated with parsing or
deserializing TOML.
Sourcepub fn source(&self) -> Option<&str>
pub fn source(&self) -> Option<&str>
Gets the TOML source code associated with the error.
Returns None if the error is not associated with parsing or
deserializing TOML.
Sourcepub fn to_diagnostic(&self) -> Diagnostic
pub fn to_diagnostic(&self) -> Diagnostic
Converts the error into a Diagnostic.