pub enum CallCachingMode {
Off,
On,
Explicit,
}Expand description
Represents the supported call caching modes.
Variants
Off
Call caching is disabled.
The call cache is not checked and new entries are not added to the cache.
This is the default value.
On
Call caching is enabled.
The call cache is checked and new entries are added to the cache.
Defaults the cacheable task hint to true.
Explicit
Call caching is enabled only for tasks that explicitly have a
cacheable hint set to true.
The call cache is checked and new entries are added to the cache only
for tasks that have the cacheable hint set to true.
Defaults the cacheable task hint to false.