pub enum ContentDigestMode {
Strong,
Strongish,
Weak,
}Expand description
Represents the supported modes for calculating content digests.
Variants
Strong
Use a strong digest for file content.
Strong digests require hashing all of the contents of a file; this may noticeably impact performance for very large files.
This setting guarantees that a modified file will be detected.
Strongish
Use a “strongish” digest for file content.
A strongish digest is based off of the file’s size, last modified
time, and a hash of only the first 10 MiB of the file’s contents;
this is similar to Cromwell’s fingerprint call caching strategy.
This setting cannot guarantee the detection of modified files (e.g. a modification beyond the first 10 MiB of a file without a change to its size or last modified time will not be detected), but it is faster than using a strong digest for large files while still taking file content into account.
Weak
Use a weak digest for file content.
A weak digest is based solely off of file metadata, such as size and last modified time.
This setting cannot guarantee the detection of modified files and may result in a modified file not causing a call cache entry to be invalidated.
However, it is substantially faster than using a strong digest.