pub enum FailureMode {
Slow,
Fast,
}Expand description
Represents how an evaluation error or cancellation should be handled by the engine.
Variants
Slow
When an error is encountered or evaluation is canceled, evaluation waits for any outstanding tasks to complete.
Fast
When an error is encountered or evaluation is canceled, any outstanding tasks that are executing are immediately canceled and evaluation waits for cancellation to complete.