pub enum Retries {
Default,
Use(u64),
}Expand description
Represents the maximum number of retries for tasks.
Variants
Default
Use the default number of retries for task execution.
Use(u64)
Use the specified number of retries for task execution.