pub struct AdditionalArgs {
pub args: Vec<String>,
pub conditional: Vec<ConditionalArgs>,
}Expand description
Represents additional arguments to the Slurm and LSF backends.
These arguments are passed to the executable responsible for queuing a task.
Fields
args: Vec<String>The additional arguments to pass to the backend program.
conditional: Vec<ConditionalArgs>The conditional arguments to pass to the backend program.
The first conditional argument with an associated conditional expression
that evaluates to true will be passed to the backend program.
Implementations