pub struct AzureStorageConfig {
pub auth: IndexMap<String, IndexMap<String, SecretString>>,
}Expand description
Represents configuration for Azure Blob Storage.
Fields
auth: IndexMap<String, IndexMap<String, SecretString>>The Azure Blob Storage authentication configuration.
The key for the outer map is the Azure Storage account name.
The key for the inner map is the Azure Storage container name.
The value for the inner map is the SAS token to apply for requests to the Azure Storage container.
Implementations