pub struct Condition {
pub raw: String,
/* private fields */
}Expand description
Represents a condition in a conditional argument.
The expression is evaluated in a context where a task’s computed cpu,
memory, gpu, fpga, and disks values and evaluated hint object are
available as variables.
The expression is type checked during configuration deserialization to
ensure it is a valid WDL expression of type Boolean.
Fields
raw: StringThe raw WDL expression string.
Implementations