ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder<T> { /* private fields */ }
Implements a configuration builder.

The builder supports merging multiple TOML configuration files together.

Merging works by the following:

  • Matching table keys that are arrays get appended.
  • Matching table keys that are tables are recursively merged.
  • Otherwise, the value associated with the key is replaced by the configuration being merged in.

The configuration builder is generic so that it can build any type that supports TOML serialization.

Implementations

Source

impl<T> ConfigBuilder<T>

pub fn with_string_source(self, toml: impl Into<String>) -> Self

Adds a TOML string source to the builder.

pub fn with_file_source(self, path: impl Into<PathBuf>) -> Self

Adds a TOML configuration file source to the builder.

pub fn try_build(self) -> Result<T, BuilderError>
where T: ToToml + for<'de> FromToml<'de>,

Attempts to build the configuration.

Each configuration file is merged with the previous one in the order they were added to the builder.