pub struct GoogleStorageConfig {
pub auth: HashMap<String, String>,
}Expand description
Represents configuration for Google Cloud Storage.
Fields
auth: HashMap<String, String>The Google Cloud Storage authentication configuration.
The key for the map is the bucket name.
The value for the map is the presigned query string.
Implementations