pub struct HttpConfig {
pub cache_dir: String,
pub retries: u32,
pub parallelism: Parallelism,
pub hash_algorithm: HashAlgorithm,
}Expand description
Represents HTTP configuration.
Fields
cache_dir: StringThe HTTP download cache location.
Defaults to an operating system specific cache directory for the user.
retries: u32The number of retries for transferring files.
parallelism: ParallelismThe maximum parallelism for file transfers.
Defaults to the host’s available parallelism.
hash_algorithm: HashAlgorithmThe hash algorithm to use for calculating content digests for file uploads.
Defaults to sha256.
Implementations