pub struct LsfApptainerBackendConfig {
pub interval: Option<u64>,
pub max_concurrency: Option<u32>,
pub default_lsf_queue: Option<LsfQueueConfig>,
pub short_task_lsf_queue: Option<LsfQueueConfig>,
pub gpu_lsf_queue: Option<LsfQueueConfig>,
pub fpga_lsf_queue: Option<LsfQueueConfig>,
pub extra_bsub_args: Option<Vec<String>>,
pub job_name_prefix: Option<String>,
pub apptainer_config: ApptainerConfig,
}Expand description
Configuration for the LSF + Apptainer backend.
Fields
interval: Option<u64>The task monitor polling interval, in seconds.
Defaults to 30 seconds.
max_concurrency: Option<u32>The maximum number of concurrent LSF operations the backend will perform.
This controls the maximum concurrent number of bsub processes the
backend will spawn to queue tasks.
Defaults to 10 concurrent operations.
default_lsf_queue: Option<LsfQueueConfig>Which queue, if any, to specify when submitting normal jobs to LSF.
This may be superseded by
short_task_lsf_queue,
gpu_lsf_queue, or
fpga_lsf_queue for corresponding tasks.
short_task_lsf_queue: Option<LsfQueueConfig>Which queue, if any, to specify when submitting short tasks to LSF.
This may be superseded by gpu_lsf_queue or
fpga_lsf_queue for tasks which require
specialized hardware.
gpu_lsf_queue: Option<LsfQueueConfig>Which queue, if any, to specify when submitting tasks which require a GPU to LSF.
fpga_lsf_queue: Option<LsfQueueConfig>Which queue, if any, to specify when submitting tasks which require an FPGA to LSF.
extra_bsub_args: Option<Vec<String>>Additional command-line arguments to pass to bsub when submitting jobs
to LSF.
job_name_prefix: Option<String>Prefix to add to every LSF job name before the task identifier. This is truncated as needed to satisfy the byte-oriented LSF job name limit.
apptainer_config: ApptainerConfigThe configuration of Apptainer, which is used as the container runtime on the compute nodes where LSF dispatches tasks.
Note that this will likely be replaced by an abstraction over multiple container execution runtimes in the future, rather than being hardcoded to Apptainer.
Implementations