pub struct TaskConfig {
pub retries: Option<u64>,
pub container: Option<String>,
pub shell: Option<String>,
pub cpu_limit_behavior: TaskResourceLimitBehavior,
pub memory_limit_behavior: TaskResourceLimitBehavior,
pub cache_dir: Option<PathBuf>,
pub cache: CallCachingMode,
pub digests: ContentDigestMode,
}Expand description
Represents task evaluation configuration.
Fields
retries: Option<u64>The default maximum number of retries to attempt if a task fails.
A task’s max_retries requirement will override this value.
Defaults to 0 (no retries).
container: Option<String>The default container to use if a container is not specified in a task’s requirements.
Defaults to ubuntu:latest.
shell: Option<String>The default shell to use for tasks.
Defaults to bash.
The shell must support a -c option to run a specific script file (i.e.
an evaluated task command).
Note that this option affects all task commands, so every container that is used must contain the specified shell.
If using this setting causes your tasks to fail, please do not file an issue.
cpu_limit_behavior: TaskResourceLimitBehaviorThe behavior when a task’s cpu requirement cannot be met.
memory_limit_behavior: TaskResourceLimitBehaviorThe behavior when a task’s memory requirement cannot be met.
cache_dir: Option<PathBuf>The call cache directory to use for caching task execution results.
Defaults to an operating system specific cache directory for the user.
cache: CallCachingModeThe call caching mode to use for tasks.
digests: ContentDigestModeThe content digest mode to use.
Used as part of call caching.
Implementations