pub enum CancellationContextState {
NotCanceled,
Waiting,
Canceling,
}Expand description
Represents the current state of a CancellationContext.
Variants
NotCanceled
The context has not been canceled yet.
Waiting
The context has been canceled and is waiting for executing tasks to complete.
Canceling
The context has been canceled and is waiting for executing tasks to cancel.