pub enum EngineEvent {
ReusedCachedExecutionResult {
id: String,
},
TaskParked,
TaskUnparked {
canceled: bool,
},
}Expand description
Represents an event from the WDL evaluation engine.
Variants
ReusedCachedExecutionResult
A cached task execution result was reused due to a call cache hit.
TaskParked
A locally running task has been parked by the engine due to insufficient resources.
TaskUnparked
A locally running task has been unparked by the engine.