pub enum HiddenValue {
Hints(HintsValue),
Input(InputValue),
Output(OutputValue),
TaskPreEvaluation(TaskPreEvaluationValue),
TaskPostEvaluation(TaskPostEvaluationValue),
PreviousTaskData(PreviousTaskDataValue),
}Expand description
Represents a hidden value.
Hidden values are cheap to clone.
Variants
Hints(HintsValue)
The value is a hints value.
Hints values only appear in a task hints section in WDL 1.2.
Input(InputValue)
The value is an input value.
Input values only appear in a task hints section in WDL 1.2.
Output(OutputValue)
The value is an output value.
Output values only appear in a task hints section in WDL 1.2.
TaskPreEvaluation(TaskPreEvaluationValue)
The value is a task variable before evaluation.
This value occurs during requirements, hints, and runtime section evaluation in WDL 1.3+ tasks.
TaskPostEvaluation(TaskPostEvaluationValue)
The value is a task variable after evaluation.
This value occurs during command and output section evaluation in WDL 1.2+ tasks.
PreviousTaskData(PreviousTaskDataValue)
The value is a previous requirements value.
This value contains the previous attempt’s requirements and is available
in WDL 1.3+ via task.previous.
Implementations