Inputs

Enum Inputs 

pub enum Inputs {
    Task(TaskInputs),
    Workflow(WorkflowInputs),
}
Represents inputs to a WDL workflow or task.

Variants



Task(TaskInputs)

The inputs are to a task.



Workflow(WorkflowInputs)

The inputs are to a workflow.

Implementations

Source

impl Inputs

pub fn parse( document: &Document, path: impl AsRef<Path>, ) -> Result<Option<(String, Self)>>

Parses an inputs file from the given file path.

The format (JSON or YAML) is determined by the file extension:

  • .json for JSON format
  • .yml or .yaml for YAML format

The parse uses the provided document to validate the input keys within the file.

Returns Ok(Some(_)) if the inputs are not empty.

Returns Ok(None) if the inputs are empty.

pub fn parse_json( document: &Document, path: impl AsRef<Path>, ) -> Result<Option<(String, Self)>>

Parses a JSON inputs file from the given file path.

The parse uses the provided document to validate the input keys within the file.

Returns Ok(Some(_)) if the inputs are not empty.

Returns Ok(None) if the inputs are empty.

pub fn parse_yaml( document: &Document, path: impl AsRef<Path>, ) -> Result<Option<(String, Self)>>

Parses a YAML inputs file from the given file path.

The parse uses the provided document to validate the input keys within the file.

Returns Ok(Some(_)) if the inputs are not empty.

Returns Ok(None) if the inputs are empty.

pub fn is_empty(&self) -> bool

Determines if the inputs are empty.

pub fn len(&self) -> usize

Gets the length of all inputs.

For task inputs, this include the inputs, requirements, and hints.

For workflow inputs, this includes the inputs and nested inputs.

pub fn get(&self, name: &str) -> Option<&Value>

Gets an input value.

pub fn set( &mut self, name: impl Into<String>, value: impl Into<Value>, ) -> Option<Value>

Sets an input value.

Returns the previous value, if any.

pub fn as_task_inputs(&self) -> Option<&TaskInputs>

Gets the task inputs.

Returns None if the inputs are for a workflow.

pub fn as_task_inputs_mut(&mut self) -> Option<&mut TaskInputs>

Gets a mutable reference to task inputs.

Returns None if the inputs are for a workflow.

pub fn unwrap_task_inputs(self) -> TaskInputs

Unwraps the inputs as task inputs.

Panics

Panics if the inputs are for a workflow.

pub fn as_workflow_inputs(&self) -> Option<&WorkflowInputs>

Gets the workflow inputs.

Returns None if the inputs are for a task.

pub fn as_workflow_inputs_mut(&mut self) -> Option<&mut WorkflowInputs>

Gets a mutable reference to workflow inputs.

Returns None if the inputs are for a task.

pub fn unwrap_workflow_inputs(self) -> WorkflowInputs

Unwraps the inputs as workflow inputs.

Panics

Panics if the inputs are for a task.

pub fn parse_json_object( document: &Document, object: JsonMap, ) -> Result<Option<(String, Self)>>

Parses the root object in a JsonMap.

Returns Ok(Some(_)) if the inputs are not empty.

Returns Ok(None) if the inputs are empty.