pub enum PrimitiveValue {
Boolean(bool),
Integer(i64),
Float(OrderedFloat<f64>),
String(Arc<String>),
File(HostPath),
Directory(HostPath),
}Expand description
Represents a primitive WDL value.
Primitive values are cheap to clone.
Variants
Boolean(bool)
The value is a Boolean.
Integer(i64)
The value is an Int.
Float(OrderedFloat<f64>)
The value is a Float.
String(Arc<String>)
The value is a String.
File(HostPath)
The value is a File.
Directory(HostPath)
The value is a Directory.
Implementations
Sourceimpl PrimitiveValue
impl PrimitiveValue
Sourcepub fn new_string(s: impl Into<String>) -> Self
pub fn new_string(s: impl Into<String>) -> Self
Creates a new String value.
Sourcepub fn new_directory(path: impl Into<HostPath>) -> Self
pub fn new_directory(path: impl Into<HostPath>) -> Self
Creates a new Directory value.
Sourcepub fn as_boolean(&self) -> Option<bool>
pub fn as_boolean(&self) -> Option<bool>
Gets the value as a Boolean.
Returns None if the value is not a Boolean.
Sourcepub fn unwrap_boolean(self) -> bool
pub fn unwrap_boolean(self) -> bool
Sourcepub fn as_integer(&self) -> Option<i64>
pub fn as_integer(&self) -> Option<i64>
Gets the value as an Int.
Returns None if the value is not an Int.
Sourcepub fn unwrap_integer(self) -> i64
pub fn unwrap_integer(self) -> i64
Sourcepub fn as_float(&self) -> Option<f64>
pub fn as_float(&self) -> Option<f64>
Gets the value as a Float.
Returns None if the value is not a Float.
Sourcepub fn unwrap_float(self) -> f64
pub fn unwrap_float(self) -> f64
Sourcepub fn as_string(&self) -> Option<&Arc<String>>
pub fn as_string(&self) -> Option<&Arc<String>>
Gets the value as a String.
Returns None if the value is not a String.
Sourcepub fn unwrap_string(self) -> Arc<String>
pub fn unwrap_string(self) -> Arc<String>
Sourcepub fn as_file(&self) -> Option<&HostPath>
pub fn as_file(&self) -> Option<&HostPath>
Gets the value as a File.
Returns None if the value is not a File.
Sourcepub fn unwrap_file(self) -> HostPath
pub fn unwrap_file(self) -> HostPath
Sourcepub fn as_directory(&self) -> Option<&HostPath>
pub fn as_directory(&self) -> Option<&HostPath>
Gets the value as a Directory.
Returns None if the value is not a Directory.
Sourcepub fn unwrap_directory(self) -> HostPath
pub fn unwrap_directory(self) -> HostPath