pub fn convert_unit_string(s: &str) -> Option<u64>Expand description
Converts a unit string (e.g. 2 GiB) to bytes.
The string is expected to contain a single integer followed by the unit.
Returns None if the string is not a valid unit string or if the resulting
byte count exceeds an unsigned 64-bit integer.