nullable_config_type

Macro nullable_config_type 

macro_rules! nullable_config_type {
    (
        $name:ident,
        $inner:ty,
        $sentinel:literal,
        $value:ident,
        $validation:expr,
        $expected:literal,
        $default:expr
    ) => { ... };
}
Creates a new type, which can be nulled, for use in configuration structs.

The inner type cannot be a String or the sentinel value will never be recognized.