Module path

Module path 

Representation of evaluation paths that support URLs.

Enums

EvaluationPath
Represents a path used in evaluation that may be either local or remote.

Functions

has_supported_scheme
Returns true if the given URL has a scheme supported by this crate.
is_file_url
Determines if the given string is prefixed with a file URL scheme.
is_supported_url
Determines if the given string is prefixed with a supported URL scheme.
parse_supported_url
Parses a string into a URL.