pub enum EvaluationPath {
Local(PathBuf),
Remote(Url),
}Expand description
Represents a path used in evaluation that may be either local or remote.
Variants
Implementations
Sourceimpl EvaluationPath
impl EvaluationPath
Sourcepub fn to_str(&self) -> Option<&str>
pub fn to_str(&self) -> Option<&str>
Gets a string representation of the path.
Returns None if the path is local and cannot be represented in UTF-8.
Sourcepub fn as_local(&self) -> Option<&Path>
pub fn as_local(&self) -> Option<&Path>
Converts the path to a local path.
Returns None if the path is remote.
Sourcepub fn unwrap_local(self) -> PathBuf
pub fn unwrap_local(self) -> PathBuf
Sourcepub fn as_remote(&self) -> Option<&Url>
pub fn as_remote(&self) -> Option<&Url>
Converts the path to a remote URL.
Returns None if the path is local.
Sourcepub fn unwrap_remote(self) -> Url
pub fn unwrap_remote(self) -> Url