pub struct ApptainerState { /* private fields */ }Expand description
The state of an Apptainer backend for a given top-level execution.
As Apptainer-converted images are shared throughout all task executions of a given invocation, only one of these state structures should be constructed per top-level task/workflow execution.
Implementations
Sourceimpl ApptainerState
impl ApptainerState
Sourcepub fn new(config: &ApptainerConfig, run_root_dir: &Path) -> Self
pub fn new(config: &ApptainerConfig, run_root_dir: &Path) -> Self
Create a new ApptainerState.
Sourcepub async fn prepare_apptainer_command(
&self,
container: &str,
cancellation_token: CancellationToken,
spawn_request: &TaskSpawnRequest,
) -> Result<String, Error>
pub async fn prepare_apptainer_command( &self, container: &str, cancellation_token: CancellationToken, spawn_request: &TaskSpawnRequest, ) -> Result<String, Error>
Prepare for an Apptainer execution by ensuring the image cache is
populated with the necessary container, and return a Bash script
that invokes the task’s command in the container context.
Shared filesystem assumptions
The returned script should be run in an environment that shares a
filesystem with the environment where this method is invoked, except
for node-specific mounts like /tmp and /var. This assumption
typically holds on HPC systems with shared filesystems like Lustre or
GPFS.