pub struct Array { /* private fields */ }Expand description
Represents an Array value.
Arrays are cheap to clone.
Implementations
Sourceimpl Array
impl Array
Sourcepub fn new<V>(
context: Option<&dyn EvaluationContext>,
ty: impl Into<Type>,
elements: impl IntoIterator<Item = V>,
) -> Result<Self>
pub fn new<V>( context: Option<&dyn EvaluationContext>, ty: impl Into<Type>, elements: impl IntoIterator<Item = V>, ) -> Result<Self>
Creates a new Array value for the given array type.
Returns an error if an element did not coerce to the array’s element type.
Panics
Panics if the given type is not an array type.