pub struct CancellationContext { /* private fields */ }Expand description
Represents context for cancelling workflow or task evaluation.
Uses a default failure mode of Slow.
Implementations
Sourceimpl CancellationContext
impl CancellationContext
Sourcepub fn new(mode: FailureMode) -> Self
pub fn new(mode: FailureMode) -> Self
Constructs a cancellation context for the given FailureMode.
If the provided mode is Slow, the first call to
cancel will wait for currently executing tasks to
complete; a subsequent call to cancel will cancel the
currently executing tasks.
If the provided mode is Fast, the first call to
cancel will cancel the currently executing tasks.
Sourcepub fn state(&self) -> CancellationContextState
pub fn state(&self) -> CancellationContextState
Gets the CancellationContextState of this CancellationContext.
Sourcepub fn cancel(&self) -> CancellationContextState
pub fn cancel(&self) -> CancellationContextState
Performs a cancellation.
Returns the current CancellationContextState which should be checked
to ensure the desired cancellation occurred.
This method will never return a
CancellationContextState::NotCanceled state.
Sourcepub fn first(&self) -> CancellationToken
pub fn first(&self) -> CancellationToken
Gets the cancellation token that is canceled upon the first cancellation.
The token will be canceled when CancellationContext::cancel is
called and the resulting state is CancellationContextState::Waiting
or CancellationContextState::Canceling.
Callers should not directly cancel the returned token and instead call
CancellationContext::cancel.
Sourcepub fn second(&self) -> CancellationToken
pub fn second(&self) -> CancellationToken
Gets the cancellation token that is canceled upon the second cancellation when the failure mode is “slow” or first cancellation when the failure mode is “fast”.
The token will be canceled when CancellationContext::cancel is
called and the resulting state is
CancellationContextState::Canceling.
Callers should not directly cancel the returned token and instead call
CancellationContext::cancel.