Crate wdl_engine

Crate wdl_engine 

Execution engine for Workflow Description Language (WDL) documents.

Re-exports

pub use config::Config;

Modules

config
Implementation of engine configuration.
v1
Implementation of evaluation for V1 documents.

Structs

Array
Represents an Array value.
CallLocation
Represents the location of a call in an evaluation error.
CallValue
Represents the outputs of a call.
CancellationContext
Represents context for cancelling workflow or task evaluation.
EnumVariant
An enum variant value.
EvaluatedTask
Represents an evaluated task.
EvaluationPath
Represents a path used in evaluation that may be either local or remote.
Events
Represents events that may be sent during WDL evaluation.
GuestPath
Represents a path to a file or directory on the guest.
HintsValue
Represents a hints value from a WDL 1.2 hints section.
HostPath
Represents a path to a file or directory on the host file system or a URL to a remote file.
InputValue
Represents an input value from a WDL 1.2 hints section.
Map
Represents a Map value.
Object
Represents an Object value.
OutputValue
Represents an output value from a WDL 1.2 hints section.
Outputs
Represents outputs of a WDL workflow or task.
Pair
Represents a Pair value.
PreviousTaskDataValue
Represents a task.previous value containing data from a previous attempt.
SourceError
Represents an error that originates from WDL source.
Struct
Represents a Struct value.
TaskInputs
Represents inputs to a task.
TaskPostEvaluationValue
Represents a task variable value after requirements evaluation (WDL 1.2+).
TaskPreEvaluationValue
Represents a task variable value before requirements evaluation (WDL 1.3+).
WorkflowInputs
Represents inputs to a workflow.

Enums

CancellationContextState
Represents the current state of a CancellationContext.
CompoundValue
Represents a compound value.
EngineEvent
Represents an event from the WDL evaluation engine.
EvaluationError
Represents an error that may occur when evaluating a workflow or task.
HiddenValue
Represents a hidden value.
Inputs
Represents inputs to a WDL workflow or task.
PrimitiveValue
Represents a primitive WDL value.
Value
Represents a WDL runtime value.

Type Aliases

EvaluationResult
Represents a result from evaluating a workflow or task.
JsonMap
A type alias to a JSON map (object).