EnumChoice

Struct EnumChoice 

pub struct EnumChoice(/* private fields */);
An enum choice value.

An enum choice is identified by its enum type and choice name.

This type is cheaply cloneable.

Implementations

Source

impl EnumChoice

pub fn new( enum_ty: impl Into<EnumType>, name: &str, value: impl Into<Value>, ) -> Self

Attempts to create a new enum choice from an enum type and choice name.

Panics

Panics if the given choice name is not present in the given enum type.

pub fn enum_ty(&self) -> EnumType

Gets the type of the enum.

pub fn name(&self) -> &str

Gets the name of the choice.

pub fn value(&self) -> &Value

Gets the value of the choice.