pub struct EnumVariant { /* private fields */ }Expand description
An enum variant value.
A variant enum is the name of the enum variant and the type of the enum from which that variant can be looked up.
This type is cheaply cloneable.
Implementations