pub struct EvaluatedTask { /* private fields */ }Expand description
Represents an evaluated task.
An evaluated task is one that was executed by a task execution backend.
The evaluated task may have failed as a result of an unacceptable exit code.
Use EvaluatedTask::into_outputs to get the outputs of the task.
Implementations
Sourceimpl EvaluatedTask
impl EvaluatedTask
Sourcepub fn failed(&self) -> bool
pub fn failed(&self) -> bool
Gets whether or not the evaluated task failed as a result of an unacceptable exit code.
Sourcepub fn cached(&self) -> bool
pub fn cached(&self) -> bool
Determines whether or not the task execution result was used from the call cache.
Sourcepub fn work_dir(&self) -> &EvaluationPath
pub fn work_dir(&self) -> &EvaluationPath
Gets the working directory of the evaluated task.
Sourcepub fn into_outputs(self) -> EvaluationResult<Outputs>
pub fn into_outputs(self) -> EvaluationResult<Outputs>
Converts the evaluated task into its Outputs.
An error is returned if the task failed as a result of an unacceptable exit code.