pub struct Events { /* private fields */ }Expand description
Represents events that may be sent during WDL evaluation.
Implementations
Sourceimpl Events
impl Events
Sourcepub fn new(capacity: usize) -> Self
pub fn new(capacity: usize) -> Self
Constructs a new Events and enables subscribing to all event channels.
Sourcepub fn disabled() -> Self
pub fn disabled() -> Self
Constructs a new Events and disable subscribing to any event channel.
Sourcepub fn subscribe_engine(&self) -> Option<Receiver<EngineEvent>>
pub fn subscribe_engine(&self) -> Option<Receiver<EngineEvent>>
Subscribes to the WDL engine events channel.
Returns None if WDL engine events are not enabled.
Sourcepub fn subscribe_crankshaft(&self) -> Option<Receiver<CrankshaftEvent>>
pub fn subscribe_crankshaft(&self) -> Option<Receiver<CrankshaftEvent>>
Subscribes to the Crankshaft events channel.
Returns None if Crankshaft events are not enabled.
Sourcepub fn subscribe_transfer(&self) -> Option<Receiver<TransferEvent>>
pub fn subscribe_transfer(&self) -> Option<Receiver<TransferEvent>>
Subscribes to the transfer events channel.
Returns None if transfer events are not enabled.