pub struct GuestPath(/* private fields */);Expand description
Represents a path to a file or directory on the guest.
The guest in this context is the container where tasks are run.
For backends that do not use containers, a guest path is the same as a host path.
Implementations