pub struct HostPath(pub Arc<String>);Expand description
Represents a path to a file or directory on the host file system or a URL to a remote file.
The host in this context is where the WDL evaluation is taking place.
Tuple Fields
0: Arc<String>Implementations
Sourceimpl HostPath
impl HostPath
Sourcepub fn expand(&self, base_dir: &EvaluationPath) -> Result<Self>
pub fn expand(&self, base_dir: &EvaluationPath) -> Result<Self>
Shell-expands the path.
The path is also joined with the provided base directory.
Sourcepub fn is_relative(&self) -> bool
pub fn is_relative(&self) -> bool
Determines if the host path is relative.