pub struct Input { /* private fields */ }Expand description
Represents a File or Directory input to a task.
Implementations
Sourceimpl Input
impl Input
Sourcepub fn kind(&self) -> ContentKind
pub fn kind(&self) -> ContentKind
Gets the content kind of the input.
Sourcepub fn path(&self) -> &EvaluationPath
pub fn path(&self) -> &EvaluationPath
Gets the path to the input.
The path of the input may be local or remote.
Sourcepub fn guest_path(&self) -> Option<&GuestPath>
pub fn guest_path(&self) -> Option<&GuestPath>
Gets the guest path for the input.
This is None for inputs to backends that don’t use containers.
Sourcepub fn local_path(&self) -> Option<&Path>
pub fn local_path(&self) -> Option<&Path>
Gets the local path of the input.
Returns None if the input is remote and has not been localized.
Sourcepub fn set_location(&mut self, location: Location)
pub fn set_location(&mut self, location: Location)
Sets the location of the input.
This is used during localization to set a local path for remote inputs.