pub struct LocatedJsonValue {
pub origin: EvaluationPath,
pub value: Value,
}Expand description
An input value that has not yet had its paths normalized and been converted to an engine value.
Fields
origin: EvaluationPathThe location where this input was initially read, used for normalizing any paths the value may contain.
value: ValueThe raw JSON representation of the input value.