LsfApptainerBackendConfig

Struct LsfApptainerBackendConfig 

pub struct LsfApptainerBackendConfig {
    pub default_lsf_queue: Option<LsfQueueConfig>,
    pub short_task_lsf_queue: Option<LsfQueueConfig>,
    pub gpu_lsf_queue: Option<LsfQueueConfig>,
    pub fpga_lsf_queue: Option<LsfQueueConfig>,
    pub extra_bsub_args: Option<Vec<String>>,
    pub max_scatter_concurrency: u64,
    pub apptainer_config: ApptainerConfig,
}
Configuration for the LSF + Apptainer backend.

Fields

default_lsf_queue: Option<LsfQueueConfig>

Which queue, if any, to specify when submitting normal jobs to LSF.

This may be superseded by short_task_lsf_queue, gpu_lsf_queue, or fpga_lsf_queue for corresponding tasks.

short_task_lsf_queue: Option<LsfQueueConfig>

Which queue, if any, to specify when submitting short tasks to LSF.

This may be superseded by gpu_lsf_queue or fpga_lsf_queue for tasks which require specialized hardware.

gpu_lsf_queue: Option<LsfQueueConfig>

Which queue, if any, to specify when submitting tasks which require a GPU to LSF.

fpga_lsf_queue: Option<LsfQueueConfig>

Which queue, if any, to specify when submitting tasks which require an FPGA to LSF.

extra_bsub_args: Option<Vec<String>>

Additional command-line arguments to pass to bsub when submitting jobs to LSF.

max_scatter_concurrency: u64

The maximum number of scatter subtasks that can be evaluated concurrently.

By default, this is 200.

apptainer_config: ApptainerConfig

The configuration of Apptainer, which is used as the container runtime on the compute nodes where LSF dispatches tasks.

Note that this will likely be replaced by an abstraction over multiple container execution runtimes in the future, rather than being hardcoded to Apptainer.

Implementations

Source

impl LsfApptainerBackendConfig

pub async fn validate(&self, engine_config: &Config) -> Result<(), Error>

Validate that the backend is appropriately configured.