LsfQueueConfig

Struct LsfQueueConfig 

pub struct LsfQueueConfig { /* private fields */ }
Configuration for an LSF queue.

Each queue can optionally have per-task CPU and memory limits set so that tasks which are too large to be scheduled on that queue will fail immediately instead of pending indefinitely. In the future, these limits may be populated or validated by live information from the cluster, but for now they must be manually based on the user’s understanding of the cluster configuration.

Implementations

Source

impl LsfQueueConfig

pub fn new( name: String, max_cpu_per_task: Option<u64>, max_memory_per_task: Option<ByteSize>, ) -> Self

Create an LsfQueueConfig.

pub fn name(&self) -> &str

The name of the queue; this is the string passed to bsub -q <queue_name>.

pub fn max_cpu_per_task(&self) -> Option<u64>

The maximum number of CPUs this queue can provision for a single task.

pub fn max_memory_per_task(&self) -> Option<ByteSize>

The maximum memory this queue can provision for a single task.