pub struct Map { /* private fields */ }Expand description
Represents a Map value.
Maps are cheap to clone.
Implementations
Sourceimpl Map
impl Map
Sourcepub fn new<K, V>(
context: Option<&dyn EvaluationContext>,
ty: impl Into<Type>,
elements: impl IntoIterator<Item = (K, V)>,
) -> Result<Self>
pub fn new<K, V>( context: Option<&dyn EvaluationContext>, ty: impl Into<Type>, elements: impl IntoIterator<Item = (K, V)>, ) -> Result<Self>
Creates a new Map value.
Returns an error if a key or value did not coerce to the map’s key or value type, respectively.
Panics
Panics if the given type is not a map type.
Sourcepub fn iter(
&self,
) -> impl ExactSizeIterator<Item = (&Option<PrimitiveValue>, &Value)>
pub fn iter( &self, ) -> impl ExactSizeIterator<Item = (&Option<PrimitiveValue>, &Value)>
Iterates the elements of the map.
Sourcepub fn keys(&self) -> impl ExactSizeIterator<Item = &Option<PrimitiveValue>>
pub fn keys(&self) -> impl ExactSizeIterator<Item = &Option<PrimitiveValue>>
Iterates the keys of the map.
Sourcepub fn values(&self) -> impl ExactSizeIterator<Item = &Value>
pub fn values(&self) -> impl ExactSizeIterator<Item = &Value>
Iterates the values of the map.
Sourcepub fn contains_key(&self, key: &Option<PrimitiveValue>) -> bool
pub fn contains_key(&self, key: &Option<PrimitiveValue>) -> bool
Determines if the map contains the given key.