pub struct Pair { /* private fields */ }Expand description
Represents a Pair value.
Pairs are cheap to clone.
Implementations
Sourceimpl Pair
impl Pair
Sourcepub fn new(
context: Option<&dyn EvaluationContext>,
ty: impl Into<Type>,
left: impl Into<Value>,
right: impl Into<Value>,
) -> Result<Self>
pub fn new( context: Option<&dyn EvaluationContext>, ty: impl Into<Type>, left: impl Into<Value>, right: impl Into<Value>, ) -> Result<Self>
Creates a new Pair value.
Returns an error if either the left value or the right value did not
coerce to the pair’s left type or right type, respectively.
Panics
Panics if the given type is not a pair type.