pub struct SourceError {
pub document: Document,
pub diagnostic: Diagnostic,
pub backtrace: Vec<CallLocation>,
}Expand description
Represents an error that originates from WDL source.
Fields
document: DocumentThe document originating the diagnostic.
diagnostic: DiagnosticThe evaluation diagnostic.
backtrace: Vec<CallLocation>The call backtrace for the error.
An empty backtrace denotes that the error was encountered outside of a call.
The call locations are stored as most recent to least recent.