pub struct Struct { /* private fields */ }Expand description
Represents a Struct value.
Structs are cheap to clone.
Implementations
Sourceimpl Struct
impl Struct
Sourcepub fn new<S, V>(
context: Option<&dyn EvaluationContext>,
ty: impl Into<Type>,
members: impl IntoIterator<Item = (S, V)>,
) -> Result<Self>
pub fn new<S, V>( context: Option<&dyn EvaluationContext>, ty: impl Into<Type>, members: impl IntoIterator<Item = (S, V)>, ) -> Result<Self>
Creates a new struct value.
Returns an error if the struct type does not contain a member of a given name or if a value does not coerce to the corresponding member’s type.
Panics
Panics if the given type is not a struct type.
Sourcepub fn iter(&self) -> impl ExactSizeIterator<Item = (&str, &Value)>
pub fn iter(&self) -> impl ExactSizeIterator<Item = (&str, &Value)>
Iterates the members of the struct.
Sourcepub fn keys(&self) -> impl ExactSizeIterator<Item = &str>
pub fn keys(&self) -> impl ExactSizeIterator<Item = &str>
Iterates the keys of the struct.
Sourcepub fn values(&self) -> impl ExactSizeIterator<Item = &Value>
pub fn values(&self) -> impl ExactSizeIterator<Item = &Value>
Iterates the values of the struct.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Determines if the struct contains the given member name.