pub struct TaskExecutionConstraints {
pub container: Option<String>,
pub cpu: f64,
pub memory: i64,
pub gpu: Vec<String>,
pub fpga: Vec<String>,
pub disks: IndexMap<String, i64>,
}Expand description
Represents constraints applied to a task’s execution.
Fields
container: Option<String>The container the task will run in.
A value of None indicates the task will run on the host.
cpu: f64The allocated number of CPUs; must be greater than 0.
memory: i64The allocated memory in bytes; must be greater than 0.
gpu: Vec<String>A list with one specification per allocated GPU.
The specification is execution engine-specific.
If no GPUs were allocated, then the value must be an empty list.
fpga: Vec<String>A list with one specification per allocated FPGA.
The specification is execution engine-specific.
If no FPGAs were allocated, then the value must be an empty list.
disks: IndexMap<String, i64>A map with one entry for each disk mount point.
The key is the mount point and the value is the initial amount of disk space allocated, in bytes.
The execution engine must, at a minimum, provide one entry for each disk mount point requested, but may provide more.
The amount of disk space available for a given mount point may increase during the lifetime of the task (e.g., autoscaling volumes provided by some cloud services).