pub struct TaskExecutionEvents {
pub spawned: Receiver<()>,
pub completed: Receiver<Result<TaskExecutionResult>>,
}Expand description
Represents events that can be awaited on during task execution.
Fields
spawned: Receiver<()>The event for when the task has spawned and is currently executing.
completed: Receiver<Result<TaskExecutionResult>>The event for when the task has completed.
Returns the execution result.