pub struct TaskInputs { /* private fields */ }Expand description
Represents inputs to a task.
Implementations
Sourceimpl TaskInputs
impl TaskInputs
Sourcepub fn iter(&self) -> impl Iterator<Item = (&str, &Value)> + use<'_>
pub fn iter(&self) -> impl Iterator<Item = (&str, &Value)> + use<'_>
Iterates the inputs to the task.
Sourcepub fn set(
&mut self,
name: impl Into<String>,
value: impl Into<Value>,
) -> Option<Value>
pub fn set( &mut self, name: impl Into<String>, value: impl Into<Value>, ) -> Option<Value>
Sets a task input.
Returns the previous value, if any.
Sourcepub fn requirement(&self, name: &str) -> Option<&Value>
pub fn requirement(&self, name: &str) -> Option<&Value>
Gets an overridden requirement by name.
Sourcepub fn override_requirement(
&mut self,
name: impl Into<String>,
value: impl Into<Value>,
)
pub fn override_requirement( &mut self, name: impl Into<String>, value: impl Into<Value>, )
Overrides a requirement by name.
Sourcepub fn override_hint(
&mut self,
name: impl Into<String>,
value: impl Into<Value>,
)
pub fn override_hint( &mut self, name: impl Into<String>, value: impl Into<Value>, )
Overrides a hint by name.
Sourcepub async fn join_paths<'a>(
&mut self,
task: &Task,
path: impl Fn(&str) -> Result<&'a EvaluationPath>,
) -> Result<()>
pub async fn join_paths<'a>( &mut self, task: &Task, path: impl Fn(&str) -> Result<&'a EvaluationPath>, ) -> Result<()>
Replaces any File or Directory input values with joining the
specified path with the value.
This method will attempt to coerce matching input values to their expected types.