pub struct TaskPostEvaluationValue { /* private fields */ }Expand description
Represents a task variable value after requirements evaluation (WDL 1.2+).
Exposes all task fields including evaluated constraints.
Task values are cheap to clone.
Implementations
Sourceimpl TaskPostEvaluationValue
impl TaskPostEvaluationValue
Sourcepub fn container(&self) -> Option<&Arc<String>>
pub fn container(&self) -> Option<&Arc<String>>
Gets the container in which the task is executing.
Sourcepub fn gpu(&self) -> &Array
pub fn gpu(&self) -> &Array
Gets the GPU allocations for the task.
An array with one specification per allocated GPU; the specification is execution engine-specific.
Sourcepub fn fpga(&self) -> &Array
pub fn fpga(&self) -> &Array
Gets the FPGA allocations for the task.
An array with one specification per allocated FPGA; the specification is execution engine-specific.
Sourcepub fn disks(&self) -> &Map
pub fn disks(&self) -> &Map
Gets the disk allocations for the task.
A map with one entry for each disk mount point.
The key is the mount point and the value is the initial amount of disk space allocated, in bytes.
Sourcepub fn attempt(&self) -> i64
pub fn attempt(&self) -> i64
Gets current task attempt count.
The value must be 0 the first time the task is executed and incremented by 1 each time the task is retried (if any).
Sourcepub fn end_time(&self) -> Option<i64>
pub fn end_time(&self) -> Option<i64>
Gets the time by which the task must be completed, as a Unix time stamp.
A value of None indicates there is no deadline.
Sourcepub fn return_code(&self) -> Option<i64>
pub fn return_code(&self) -> Option<i64>
Gets the task’s return code.
Initially set to None, but set after task execution completes.
Sourcepub fn parameter_meta(&self) -> &Object
pub fn parameter_meta(&self) -> &Object
Gets the tasks’s parameter_meta section as an object.