pub struct TaskPreEvaluationValue { /* private fields */ }Expand description
Represents a task variable value before requirements evaluation (WDL
1.3+).
Only exposes name, id, attempt, previous, and metadata fields.
Task values are cheap to clone.
Implementations