pub struct WorkflowInputs { /* private fields */ }Expand description
Represents inputs to a workflow.
Implementations
Sourceimpl WorkflowInputs
impl WorkflowInputs
Sourcepub fn has_nested_inputs(&self) -> bool
pub fn has_nested_inputs(&self) -> bool
Determines if there are any nested inputs in the workflow inputs.
Returns true if the inputs contains nested inputs or false if it
does not.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&str, &Value)> + use<'_>
pub fn iter(&self) -> impl Iterator<Item = (&str, &Value)> + use<'_>
Iterates the inputs to the workflow.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Gets the length of the workflow inputs.
This includes the workflow inputs plus the lengths of all nested inputs.
Sourcepub fn set(
&mut self,
name: impl Into<String>,
value: impl Into<Value>,
) -> Option<Value>
pub fn set( &mut self, name: impl Into<String>, value: impl Into<Value>, ) -> Option<Value>
Sets a workflow input.
Returns the previous value, if any.
Sourcepub fn contains(&self, name: &str) -> bool
pub fn contains(&self, name: &str) -> bool
Checks if the inputs contain a value with the specified name.
This does not check nested call inputs.
Sourcepub async fn join_paths<'a>(
&mut self,
workflow: &Workflow,
path: impl Fn(&str) -> Result<&'a EvaluationPath>,
) -> Result<()>
pub async fn join_paths<'a>( &mut self, workflow: &Workflow, path: impl Fn(&str) -> Result<&'a EvaluationPath>, ) -> Result<()>
Replaces any File or Directory input values with joining the
specified path with the value.
This method will attempt to coerce matching input values to their expected types.