pub enum ProgressKind<'a> {
TaskStarted {
id: &'a str,
},
TaskRetried {
id: &'a str,
retry: u64,
},
TaskExecutionStarted {
id: &'a str,
},
TaskExecutionCompleted {
id: &'a str,
result: &'a Result<TaskExecutionResult>,
},
TaskCompleted {
id: &'a str,
result: &'a EvaluationResult<EvaluatedTask>,
},
WorkflowStarted {
id: &'a str,
},
WorkflowCompleted {
id: &'a str,
result: &'a EvaluationResult<Outputs>,
},
}Expand description
Represents the kind of progress made during evaluation.
Variants
TaskStarted
A task with the given id has started evaluation.
TaskRetried
A task has been retried.
Fields
TaskExecutionStarted
A task with the given id has started execution.
Note that a task may have multiple executions as a result of retrying failed executions.
TaskExecutionCompleted
A task with the given id has completed execution.
Fields

result: &'a Result<TaskExecutionResult>The result from the task’s execution.
This may be Err if the task failed to complete.
TaskCompleted
A task with the given id has completed evaluation.
Fields

result: &'a EvaluationResult<EvaluatedTask>The result of task evaluation.
WorkflowStarted
A workflow with the given id has started evaluation.
WorkflowCompleted
A workflow with the given id has completed evaluation.
Fields

result: &'a EvaluationResult<Outputs>The result of workflow evaluation.
Implementations