pub struct WorkflowEvaluator { /* private fields */ }Expand description
Represents a WDL V1 workflow evaluator.
This type is cheaply cloned.
Implementations
Sourceimpl WorkflowEvaluator
impl WorkflowEvaluator
Sourcepub async fn new(config: Config, token: CancellationToken) -> Result<Self>
pub async fn new(config: Config, token: CancellationToken) -> Result<Self>
Constructs a new workflow evaluator with the given evaluation configuration and cancellation token.
This method creates a default task execution backend.
Returns an error if the configuration isn’t valid.
Sourcepub fn new_with_backend(
config: Config,
backend: Arc<dyn TaskExecutionBackend>,
token: CancellationToken,
) -> Result<Self>
pub fn new_with_backend( config: Config, backend: Arc<dyn TaskExecutionBackend>, token: CancellationToken, ) -> Result<Self>
Constructs a new workflow evaluator with the given evaluation configuration, task execution backend, and cancellation token.
Returns an error if the configuration isn’t valid.
Sourcepub async fn evaluate<P, R>(
&self,
document: &Document,
inputs: WorkflowInputs,
root_dir: impl AsRef<Path>,
progress: P,
) -> EvaluationResult<Outputs>
pub async fn evaluate<P, R>( &self, document: &Document, inputs: WorkflowInputs, root_dir: impl AsRef<Path>, progress: P, ) -> EvaluationResult<Outputs>
Evaluates the workflow of the given document.
Upon success, returns the outputs of the workflow.