Crate wdl_engine

Execution engine for Workflow Description Language (WDL) documents.

Modules

config
Implementation of engine configuration.
diagnostics
Implementation of evaluation diagnostics.
path
Representation of evaluation paths that support URLs.
v1
Implementation of evaluation for V1 documents.

Structs

Array
Represents an Array value.
CallLocation
Represents the location of a call in an evaluation error.
CallValue
Represents the outputs of a call.
CompoundValueSerializer
Serializes a CompoundValue with optional serialization of pairs.
DockerBackend
Represents the Docker backend.
EvaluatedTask
Represents an evaluated task.
HintsValue
Represents a hints value from a WDL 1.2 hints section.
Input
Represents a File or Directory input to a task.
InputTrie
Represents a prefix trie based on input paths.
InputValue
Represents an input value from a WDL 1.2 hints section.
LocalBackend
Represents a task execution backend that locally executes tasks.
Map
Represents a Map value.
Object
Represents an Object value.
OutputValue
Represents an output value from a WDL 1.2 hints section.
Outputs
Represents outputs of a WDL workflow or task.
Pair
Represents a Pair value.
Scope
Represents an evaluation scope in a WDL document.
ScopeIndex
Represents an index of a scope in a collection of scopes.
ScopeRef
Represents a reference to a scope.
SourceError
Represents an error that originates from WDL source.
Struct
Represents a Struct value.
TaskExecutionConstraints
Represents constraints applied to a task’s execution.
TaskExecutionEvents
Represents events that can be awaited on during task execution.
TaskExecutionResult
Represents the result of a task’s execution.
TaskInputs
Represents inputs to a task.
TaskSpawnInfo
Represents information for spawning a task.
TaskSpawnRequest
Represents a request to spawn a task.
TaskValue
Represents a value for task variables in WDL 1.2.
TesBackend
Represents the Task Execution Service (TES) backend.
ValueSerializer
Serializes a value with optional serialization of pairs.
WorkflowInputs
Represents inputs to a workflow.

Enums

CompoundValue
Represents a compound value.
EvaluationError
Represents an error that may occur when evaluating a workflow or task.
InputKind
Gets the kind of an input.
Inputs
Represents inputs to a WDL workflow or task.
PrimitiveValue
Represents a primitive WDL value.
StorageUnit
Represents a storage unit.
Value
Represents a WDL runtime value.

Traits

Coercible
Implemented on coercible values.
EvaluationContext
Represents context to an expression evaluator.
TaskExecutionBackend
Represents a task execution backend.

Functions

convert_unit_string
Converts a unit string (e.g. 2 GiB) to bytes.

Type Aliases

EvaluationResult
Represents a result from evaluating a workflow or task.
JsonMap
A type alias to a JSON map (object).