Execution engine for Workflow Description Language (WDL) documents.
Modules
- config
- Implementation of engine configuration.
- diagnostics
- Implementation of evaluation diagnostics.
- path
- Representation of evaluation paths that support URLs.
- v1
- Implementation of evaluation for V1 documents.
Structs
- Array
- Represents an
Arrayvalue. - Call
Location - Represents the location of a call in an evaluation error.
- Call
Value - Represents the outputs of a call.
- Compound
Value Serializer - Serializes a
CompoundValuewith optional serialization of pairs. - Docker
Backend - Represents the Docker backend.
- Evaluated
Task - Represents an evaluated task.
- Hints
Value - Represents a hints value from a WDL 1.2 hints section.
- Input
- Represents a
FileorDirectoryinput to a task. - Input
Trie - Represents a prefix trie based on input paths.
- Input
Value - Represents an input value from a WDL 1.2 hints section.
- Local
Backend - Represents a task execution backend that locally executes tasks.
- Map
- Represents a
Mapvalue. - Object
- Represents an
Objectvalue. - Output
Value - Represents an output value from a WDL 1.2 hints section.
- Outputs
- Represents outputs of a WDL workflow or task.
- Pair
- Represents a
Pairvalue. - Scope
- Represents an evaluation scope in a WDL document.
- Scope
Index - Represents an index of a scope in a collection of scopes.
- Scope
Ref - Represents a reference to a scope.
- Source
Error - Represents an error that originates from WDL source.
- Struct
- Represents a
Structvalue. - Task
Execution Constraints - Represents constraints applied to a task’s execution.
- Task
Execution Events - Represents events that can be awaited on during task execution.
- Task
Execution Result - Represents the result of a task’s execution.
- Task
Inputs - Represents inputs to a task.
- Task
Spawn Info - Represents information for spawning a task.
- Task
Spawn Request - Represents a request to spawn a task.
- Task
Value - Represents a value for
taskvariables in WDL 1.2. - TesBackend
- Represents the Task Execution Service (TES) backend.
- Value
Serializer - Serializes a value with optional serialization of pairs.
- Workflow
Inputs - Represents inputs to a workflow.
Enums
- Compound
Value - Represents a compound value.
- Evaluation
Error - Represents an error that may occur when evaluating a workflow or task.
- Input
Kind - Gets the kind of an input.
- Inputs
- Represents inputs to a WDL workflow or task.
- Primitive
Value - Represents a primitive WDL value.
- Storage
Unit - Represents a storage unit.
- Value
- Represents a WDL runtime value.
Traits
- Coercible
- Implemented on coercible values.
- Evaluation
Context - Represents context to an expression evaluator.
- Task
Execution Backend - Represents a task execution backend.
Functions
- convert_
unit_ string - Converts a unit string (e.g.
2 GiB) to bytes.
Type Aliases
- Evaluation
Result - Represents a result from evaluating a workflow or task.
- JsonMap
- A type alias to a JSON map (object).