pub enum BackendConfig {
Local(LocalBackendConfig),
Docker(DockerBackendConfig),
Tes(TesBackendConfig),
LsfApptainer(LsfApptainerBackendConfig),
SlurmApptainer(SlurmApptainerBackendConfig),
}Expand description
Represents supported task execution backends.
Variants
Local(LocalBackendConfig)
Use the local task execution backend.
Docker(DockerBackendConfig)
Use the Docker task execution backend.
Tes(TesBackendConfig)
Use the TES task execution backend.
LsfApptainer(LsfApptainerBackendConfig)
Use the experimental LSF + Apptainer task execution backend.
Requires enabling experimental features.
SlurmApptainer(SlurmApptainerBackendConfig)
Use the experimental Slurm + Apptainer task execution backend.
Requires enabling experimental features.
Implementations
Sourceimpl BackendConfig
impl BackendConfig
Sourcepub async fn validate(&self, engine_config: &Config) -> Result<()>
pub async fn validate(&self, engine_config: &Config) -> Result<()>
Validates the backend configuration.
Sourcepub fn as_local(&self) -> Option<&LocalBackendConfig>
pub fn as_local(&self) -> Option<&LocalBackendConfig>
Converts the backend configuration into a local backend configuration
Returns None if the backend configuration is not local.
Sourcepub fn as_docker(&self) -> Option<&DockerBackendConfig>
pub fn as_docker(&self) -> Option<&DockerBackendConfig>
Converts the backend configuration into a Docker backend configuration
Returns None if the backend configuration is not Docker.
Sourcepub fn as_tes(&self) -> Option<&TesBackendConfig>
pub fn as_tes(&self) -> Option<&TesBackendConfig>
Converts the backend configuration into a TES backend configuration
Returns None if the backend configuration is not TES.
Sourcepub fn as_lsf_apptainer(&self) -> Option<&LsfApptainerBackendConfig>
pub fn as_lsf_apptainer(&self) -> Option<&LsfApptainerBackendConfig>
Converts the backend configuration into a LSF Apptainer backend configuration
Returns None if the backend configuration is not LSF Apptainer.
Sourcepub fn as_slurm_apptainer(&self) -> Option<&SlurmApptainerBackendConfig>
pub fn as_slurm_apptainer(&self) -> Option<&SlurmApptainerBackendConfig>
Converts the backend configuration into a Slurm Apptainer backend configuration
Returns None if the backend configuration is not Slurm Apptainer.