pub enum BackendConfig {
Local(LocalBackendConfig),
Docker(DockerBackendConfig),
Tes(Box<TesBackendConfig>),
LsfApptainer(Arc<LsfApptainerBackendConfig>),
SlurmApptainer(Arc<SlurmApptainerBackendConfig>),
}Expand description
Represents supported task execution backends.
Variants
Local(LocalBackendConfig)
Use the local task execution backend.
Docker(DockerBackendConfig)
Use the Docker task execution backend.
Tes(Box<TesBackendConfig>)
Use the TES task execution backend.
LsfApptainer(Arc<LsfApptainerBackendConfig>)
Use the experimental LSF + Apptainer task execution backend.
Requires enabling experimental features.
SlurmApptainer(Arc<SlurmApptainerBackendConfig>)
Use the experimental Slurm + Apptainer task execution backend.
Requires enabling experimental features.
Implementations
Sourceimpl BackendConfig
impl BackendConfig
Sourcepub async fn validate(&self, engine_config: &Config) -> Result<()>
pub async fn validate(&self, engine_config: &Config) -> Result<()>
Validates the backend configuration.
Sourcepub fn as_local(&self) -> Option<&LocalBackendConfig>
pub fn as_local(&self) -> Option<&LocalBackendConfig>
Converts the backend configuration into a local backend configuration
Returns None if the backend configuration is not local.
Sourcepub fn as_docker(&self) -> Option<&DockerBackendConfig>
pub fn as_docker(&self) -> Option<&DockerBackendConfig>
Converts the backend configuration into a Docker backend configuration
Returns None if the backend configuration is not Docker.
Sourcepub fn as_tes(&self) -> Option<&TesBackendConfig>
pub fn as_tes(&self) -> Option<&TesBackendConfig>
Converts the backend configuration into a TES backend configuration
Returns None if the backend configuration is not TES.