pub enum ContentDigestMode {
Strong,
Weak,
}Expand description
Represents the supported modes for calculating content digests.
Variants
Strong
Use a strong digest for file content.
Strong digests require hashing all of the contents of a file; this may noticeably impact performance for very large files.
This setting guarantees that a modified file will be detected.
Weak
Use a weak digest for file content.
A weak digest is based solely off of file metadata, such as size and last modified time.
This setting cannot guarantee the detection of modified files and may result in a modified file not causing a call cache entry to be invalidated.
However, it is substantially faster than using a strong digest.