pub enum TaskResourceLimitBehavior {
TryWithMax,
Deny,
}Expand description
The behavior when a task resource requirement, such as cpu or memory,
cannot be met.
Variants
TryWithMax
Try executing a task with the maximum amount of the resource available when the task’s corresponding requirement cannot be met.
Deny
Do not execute a task if its corresponding requirement cannot be met.
This is the default behavior.