pub struct ConditionalArgs {
pub condition: Condition,
pub args: Vec<String>,
}Expand description
Represents a set of conditional arguments for the LSF and Slurm backends.
Conditional arguments are passed to the program responsible for queuing a
task when the associated conditional expression evaluates to true.
Fields
condition: ConditionThe condition for including the arguments.
args: Vec<String>The arguments to use when the condition evaluates to true.
Implementations