Config

Struct Config 

pub struct Config {
    pub http: HttpConfig,
    pub workflow: WorkflowConfig,
    pub task: TaskConfig,
    pub backend: String,
    pub backends: IndexMap<String, BackendConfig>,
    pub storage: StorageConfig,
    pub suppress_env_specific_output: bool,
    pub experimental_features_enabled: bool,
    pub failure_mode: FailureMode,
}
Represents WDL evaluation configuration.

By default, serialization of Config will redact the values of secrets.

Use the Config::unredact method before serialization to prevent the secrets from being redacted.

Fields

http: HttpConfig

HTTP configuration.

workflow: WorkflowConfig

Workflow evaluation configuration.

task: TaskConfig

Task evaluation configuration.

backend: String

The name of the backend to use.

backends: IndexMap<String, BackendConfig>

Task execution backends configuration.

If the collection is empty and backend has the default value, the engine default backend is used.

storage: StorageConfig

Storage configuration.

suppress_env_specific_output: bool

(Experimental) Avoid environment-specific output; default is false.

If this option is true, selected error messages and log output will avoid emitting environment-specific output such as absolute paths and system resource counts.

This is largely meant to support “golden testing” where a test’s success depends on matching an expected set of outputs exactly. Cues that help users overcome errors, such as the path to a temporary directory or the number of CPUs available to the system, confound this style of testing. This flag is a best-effort experimental attempt to reduce the impact of these differences in order to allow a wider range of golden tests to be written.

experimental_features_enabled: bool

(Experimental) Whether experimental features are enabled; default is false.

Experimental features are provided to users with heavy caveats about their stability and rough edges. Use at your own risk, but feedback is quite welcome.

failure_mode: FailureMode

The failure mode for workflow or task evaluation.

A value of FailureMode::Slow will result in evaluation waiting for executing tasks to complete upon error or interruption.

A value of FailureMode::Fast will immediately attempt to cancel executing tasks upon error or interruption.

Implementations

Source

impl Config

pub async fn validate(&self) -> Result<()>

Validates the evaluation configuration.

pub fn redact(&mut self)

Redacts the secrets contained in the configuration.

By default, secrets are redacted for serialization.

pub fn unredact(&mut self)

Unredacts the secrets contained in the configuration.

Calling this method will expose secrets for serialization.

pub fn backend(&self) -> Result<Cow<'_, BackendConfig>>

Gets the backend configuration.

Returns an error if the configuration specifies a named backend that isn’t present in the configuration.