pub struct Config {
pub http: HttpConfig,
pub workflow: WorkflowConfig,
pub task: TaskConfig,
pub backend: Option<String>,
pub backends: HashMap<String, BackendConfig>,
pub storage: StorageConfig,
pub suppress_env_specific_output: bool,
}Expand description
Represents WDL evaluation configuration.
Fields
http: HttpConfigHTTP configuration.
workflow: WorkflowConfigWorkflow evaluation configuration.
task: TaskConfigTask evaluation configuration.
backend: Option<String>The name of the backend to use.
If not specified and backends has multiple entries, it will use a name
of default.
backends: HashMap<String, BackendConfig>Task execution backends configuration.
If the collection is empty and backend is not specified, the engine
default backend is used.
If the collection has exactly one entry and backend is not specified,
the singular entry will be used.
storage: StorageConfigStorage configuration.
suppress_env_specific_output: bool(Experimental) Avoid environment-specific output; default is false.
If this option is true, selected error messages and log output will
avoid emitting environment-specific output such as absolute paths
and system resource counts.
This is largely meant to support “golden testing” where a test’s success depends on matching an expected set of outputs exactly. Cues that help users overcome errors, such as the path to a temporary directory or the number of CPUs available to the system, confound this style of testing. This flag is a best-effort experimental attempt to reduce the impact of these differences in order to allow a wider range of golden tests to be written.
Implementations