pub struct Config {
pub http: HttpConfig,
pub workflow: WorkflowConfig,
pub task: TaskConfig,
pub backend: Option<String>,
pub backends: HashMap<String, BackendConfig>,
pub storage: StorageConfig,
}Expand description
Represents WDL evaluation configuration.
Fields
http: HttpConfigHTTP configuration.
workflow: WorkflowConfigWorkflow evaluation configuration.
task: TaskConfigTask evaluation configuration.
backend: Option<String>The name of the backend to use.
If not specified and backends has multiple entries, it will use a name
of default.
backends: HashMap<String, BackendConfig>Task execution backends configuration.
If the collection is empty and backend is not specified, the engine
default backend is used.
If the collection has exactly one entry and backend is not specified,
the singular entry will be used.
storage: StorageConfigStorage configuration.
Implementations