pub struct ConfigBuilder<T> { /* private fields */ }Expand description
Implements a configuration builder.
The builder supports merging multiple TOML configuration files together.
Merging works by the following:
- Matching table keys that are arrays get appended.
- Matching table keys that are tables are recursively merged.
- Otherwise, the value associated with the key is replaced by the configuration being merged in.
The configuration builder is generic so that it can build any type that supports TOML serialization.
Implementations
Sourceimpl<T> ConfigBuilder<T>
impl<T> ConfigBuilder<T>
Sourcepub fn with_string_source(self, toml: impl Into<String>) -> Self
pub fn with_string_source(self, toml: impl Into<String>) -> Self
Adds a TOML string source to the builder.
Sourcepub fn with_file_source(self, path: impl Into<PathBuf>) -> Self
pub fn with_file_source(self, path: impl Into<PathBuf>) -> Self
Adds a TOML configuration file source to the builder.