pub struct LocalBackendConfig {
pub cpu: Option<u64>,
pub memory: Option<String>,
}Expand description
Represents configuration for the local task execution backend.
Warning: the local task execution backend spawns processes on the host
directly without the use of a container; only use this backend on trusted
WDL.
Fields
cpu: Option<u64>Set the number of CPUs available for task execution.
Defaults to the number of logical CPUs for the host.
The value cannot be zero or exceed the host’s number of CPUs.
memory: Option<String>Set the total amount of memory for task execution as a unit string (e.g.
2 GiB).
Defaults to the total amount of memory for the host.
The value cannot be zero or exceed the host’s total amount of memory.
Implementations