pub struct ScatterConfig {
pub concurrency: Option<u64>,
}Expand description
Represents scatter statement evaluation configuration.
Fields
concurrency: Option<u64>The number of scatter array elements to process concurrently.
Defaults to 1000.
A value of 0 is invalid.
Lower values use less memory for evaluation and higher values may better saturate the task execution backend with tasks to execute for large scatters.
This setting does not change how many tasks an execution backend can run concurrently, but may affect how many tasks are sent to the backend to run at a time.
For example, if concurrency was set to 10 and we evaluate the
following scatters:
scatter (i in range(100)) {
call my_task
}
scatter (j in range(100)) {
call my_task as my_task2
}Here each scatter is independent and therefore there will be 20 calls (10 for each scatter) made concurrently. If the task execution backend can only execute 5 tasks concurrently, 5 tasks will execute and 15 will be “ready” to execute and waiting for an executing task to complete.
If instead we evaluate the following scatters:
scatter (i in range(100)) {
scatter (j in range(100)) {
call my_task
}
}Then there will be 100 calls (10*10 as 10 are made for each outer element) made concurrently. If the task execution backend can only execute 5 tasks concurrently, 5 tasks will execute and 95 will be “ready” to execute and waiting for an executing task to complete.
Implementations