pub struct SlurmApptainerBackendConfig {
pub interval: Option<u64>,
pub max_concurrency: Option<u32>,
pub default_slurm_partition: Option<SlurmPartitionConfig>,
pub short_task_slurm_partition: Option<SlurmPartitionConfig>,
pub gpu_slurm_partition: Option<SlurmPartitionConfig>,
pub fpga_slurm_partition: Option<SlurmPartitionConfig>,
pub extra_sbatch_args: Option<Vec<String>>,
pub job_name_prefix: Option<String>,
pub apptainer_config: ApptainerConfig,
}Expand description
Configuration for the Slurm + Apptainer backend.
Fields
interval: Option<u64>The task monitor polling interval, in seconds.
Defaults to 30 seconds.
max_concurrency: Option<u32>The maximum number of concurrent Slurm operations the backend will perform.
This controls the maximum concurrent number of sbatch processes the
backend will spawn to queue tasks.
Defaults to 10 concurrent operations.
default_slurm_partition: Option<SlurmPartitionConfig>Which partition, if any, to specify when submitting normal jobs to Slurm.
This may be superseded by
short_task_slurm_partition,
gpu_slurm_partition, or
fpga_slurm_partition for corresponding
tasks.
short_task_slurm_partition: Option<SlurmPartitionConfig>Which partition, if any, to specify when submitting short tasks to Slurm.
This may be superseded by
gpu_slurm_partition or
fpga_slurm_partition for tasks which
require specialized hardware.
gpu_slurm_partition: Option<SlurmPartitionConfig>Which partition, if any, to specify when submitting tasks which require a GPU to Slurm.
fpga_slurm_partition: Option<SlurmPartitionConfig>Which partition, if any, to specify when submitting tasks which require an FPGA to Slurm.
extra_sbatch_args: Option<Vec<String>>Additional command-line arguments to pass to sbatch when submitting
jobs to Slurm.
job_name_prefix: Option<String>Prefix to add to every Slurm job name before the task identifier.
apptainer_config: ApptainerConfigThe configuration of Apptainer, which is used as the container runtime on the compute nodes where Slurm dispatches tasks.
Note that this will likely be replaced by an abstraction over multiple container execution runtimes in the future, rather than being hardcoded to Apptainer.
Implementations