SlurmPartitionConfig

Struct SlurmPartitionConfig 

pub struct SlurmPartitionConfig {
    pub name: String,
    pub max_cpu_per_task: Option<u64>,
    pub max_memory_per_task: Option<ByteSize>,
}
Configuration for a Slurm partition.

Each partition can optionally have per-task CPU and memory limits set so that tasks which are too large to be scheduled on that partition will fail immediately instead of pending indefinitely. In the future, these limits may be populated or validated by live information from the cluster, but for now they must be manually based on the user’s understanding of the cluster configuration.

Fields

name: String

The name of the partition; this is the string passed to sbatch --partition=<partition_name>.

max_cpu_per_task: Option<u64>

The maximum number of CPUs this partition can provision for a single task.

max_memory_per_task: Option<ByteSize>

The maximum memory this partition can provision for a single task.

Implementations

Source

impl SlurmPartitionConfig

pub async fn validate(&self, name: &str) -> Result<(), Error>

Validate that this Slurm partition exists according to the local sinfo.