Representation of evaluation paths that support URLs.
Enums
- Evaluation
Path - Represents a path used in evaluation that may be either local or remote.
Functions
- is_
file_ url - Determines if the given string is prefixed with a
fileURL scheme. - is_url
- Determines if the given string is prefixed with a supported URL scheme.
- parse_
url - Parses a string into a URL.