Enum EvaluationPath

pub enum EvaluationPath {
    Local(PathBuf),
    Remote(Url),
}
Represents a path used in evaluation that may be either local or remote.

Variants



Local(PathBuf)

The path is local (i.e. on the host).



Remote(Url)

The path is remote.

Implementations

Source

impl EvaluationPath

pub fn join(&self, path: &str) -> Result<Self>

Joins the given path to this path.

pub fn from_primitive_value(v: &PrimitiveValue) -> Result<Self>

Creates a path from a primitive File or Directory value.

pub fn to_str(&self) -> Option<&str>

Gets a string representation of the path.

Returns None if the path is local and cannot be represented in UTF-8.

pub fn as_local(&self) -> Option<&Path>

Converts the path to a local path.

Returns None if the path is remote.

pub fn unwrap_local(self) -> PathBuf

Unwraps the path to a local path.

Panics

Panics if the path is remote.

pub fn as_remote(&self) -> Option<&Url>

Converts the path to a remote URL.

Returns None if the path is local.

pub fn unwrap_remote(self) -> Url

Unwraps the path to a remote URL.

Panics

Panics if the path is local.

pub fn file_name(&self) -> Result<Option<&str>>

Gets the file name of the path.

Returns Ok(None) if the path does not contain a file name (i.e. is root).

Returns an error if the file name is not UTF-8.

pub fn display(&self) -> impl Display

Returns a display implementation for the path.