CancellationContext

Struct CancellationContext 

pub struct CancellationContext { /* private fields */ }
Represents context for cancelling workflow or task evaluation.

Uses a default failure mode of Slow.

Implementations

Source

impl CancellationContext

pub fn new(mode: FailureMode) -> Self

Constructs a cancellation context for the given FailureMode.

If the provided mode is Slow, the first call to cancel will wait for currently executing tasks to complete; a subsequent call to cancel will cancel the currently executing tasks.

If the provided mode is Fast, the first call to cancel will cancel the currently executing tasks.

pub fn state(&self) -> CancellationContextState

pub fn cancel(&self) -> CancellationContextState

Performs a cancellation.

Returns the current CancellationContextState which should be checked to ensure the desired cancellation occurred.

This method will never return a CancellationContextState::NotCanceled state.

pub fn first(&self) -> CancellationToken

Gets the cancellation token that is canceled upon the first cancellation.

The token will be canceled when CancellationContext::cancel is called and the resulting state is CancellationContextState::Waiting or CancellationContextState::Canceling.

Callers should not directly cancel the returned token and instead call CancellationContext::cancel.

pub fn second(&self) -> CancellationToken

Gets the cancellation token that is canceled upon the second cancellation when the failure mode is “slow” or first cancellation when the failure mode is “fast”.

The token will be canceled when CancellationContext::cancel is called and the resulting state is CancellationContextState::Canceling.

Callers should not directly cancel the returned token and instead call CancellationContext::cancel.