EnumVariant

Struct EnumVariant 

pub struct EnumVariant { /* private fields */ }
An enum variant value.

A variant enum is the name of the enum variant and the type of the enum from which that variant can be looked up.

This type is cheaply cloneable.

Implementations

Source

impl EnumVariant

pub fn new( enum_ty: impl Into<EnumType>, name: &str, value: impl Into<Value>, ) -> Self

Attempts to create a new enum variant from a enum type and variant name.

Panics

Panics if the given variant name is not present in the given enum type.

pub fn enum_ty(&self) -> EnumType

Gets the type of the enum.

pub fn name(&self) -> &str

Gets the name of the variant.

pub fn value(&self) -> &Value

Gets the value of the variant.