pub struct EvaluatedTask { /* private fields */ }Expand description
Represents an evaluated task.
Implementations
Sourceimpl EvaluatedTask
impl EvaluatedTask
Sourcepub fn attempt_dir(&self) -> &Path
pub fn attempt_dir(&self) -> &Path
Gets the attempt directory of the task.
Sourcepub fn work_dir(&self) -> &EvaluationPath
pub fn work_dir(&self) -> &EvaluationPath
Gets the working directory of the evaluated task.
Sourcepub fn outputs(&self) -> &EvaluationResult<Outputs>
pub fn outputs(&self) -> &EvaluationResult<Outputs>
Gets the outputs of the evaluated task.
This is Ok when the task executes successfully and all of the task’s
outputs evaluated without error.
Otherwise, this contains the error that occurred while attempting to evaluate the task’s outputs.
Sourcepub fn into_result(self) -> EvaluationResult<Outputs>
pub fn into_result(self) -> EvaluationResult<Outputs>
Converts the evaluated task into an evaluation result.
Returns Ok(_) if the task outputs were evaluated.
Returns Err(_) if the task outputs could not be evaluated.