pub struct Events { /* private fields */ }Expand description
Represents events that may be sent during evaluation.
Implementations
Sourceimpl Events
impl Events
Sourcepub fn all(capacity: usize) -> Self
pub fn all(capacity: usize) -> Self
Constructs a new Events and enables subscribing to all event channels.
Sourcepub fn crankshaft_only(capacity: usize) -> Self
pub fn crankshaft_only(capacity: usize) -> Self
Constructs a new Events and enable subscribing to only the Crankshaft
events channel.
Sourcepub fn transfer_only(capacity: usize) -> Self
pub fn transfer_only(capacity: usize) -> Self
Constructs a new Events and enable subscribing to only the transfer
events channel.
Sourcepub fn subscribe_crankshaft(&self) -> Option<Receiver<CrankshaftEvent>>
pub fn subscribe_crankshaft(&self) -> Option<Receiver<CrankshaftEvent>>
Subscribes to the Crankshaft events channel.
Returns None if Crankshaft events are not enabled.
Sourcepub fn subscribe_transfer(&self) -> Option<Receiver<TransferEvent>>
pub fn subscribe_transfer(&self) -> Option<Receiver<TransferEvent>>
Subscribes to the transfer events channel.
Returns None if transfer events are not enabled.