pub struct Input { /* private fields */ }Expand description
Represents a File or Directory input to a task.
Implementations
Sourceimpl Input
impl Input
Sourcepub fn new(kind: InputKind, path: EvaluationPath) -> Self
pub fn new(kind: InputKind, path: EvaluationPath) -> Self
Creates a new input with the given path and access.
Sourcepub fn from_primitive(value: &PrimitiveValue) -> Result<Self>
pub fn from_primitive(value: &PrimitiveValue) -> Result<Self>
Creates an input from a primitive value.
Sourcepub fn path(&self) -> &EvaluationPath
pub fn path(&self) -> &EvaluationPath
Gets the path to the input.
Sourcepub fn location(&self) -> Option<&Path>
pub fn location(&self) -> Option<&Path>
Gets the location of the input if it has been downloaded.
Sourcepub fn set_location(&mut self, location: Location<'static>)
pub fn set_location(&mut self, location: Location<'static>)
Sets the location of the input.
Sourcepub fn guest_path(&self) -> Option<&str>
pub fn guest_path(&self) -> Option<&str>
Gets the guest path for the input.
Sourcepub fn set_guest_path(&mut self, path: impl Into<String>)
pub fn set_guest_path(&mut self, path: impl Into<String>)
Sets the guest path for the input.