pub struct LocalBackend { /* private fields */ }Expand description
Represents a task execution backend that locally executes tasks.
Warning: the local task execution backend spawns processes on the host
directly without the use of a container; only use this backend on trusted
WDL.
Implementations
Sourceimpl LocalBackend
impl LocalBackend