LsfApptainerBackendConfig

Struct LsfApptainerBackendConfig 

pub struct LsfApptainerBackendConfig {
    pub default_lsf_queue: Option<String>,
    pub short_task_lsf_queue: Option<String>,
    pub gpu_lsf_queue: Option<String>,
    pub fpga_lsf_queue: Option<String>,
    pub extra_bsub_args: Option<Vec<String>>,
    pub max_scatter_concurrency: u64,
    pub extra_apptainer_exec_args: Option<Vec<String>>,
    pub apptainer_images_dir: PathBuf,
}
Configuration for the LSF + Apptainer backend.

Fields

default_lsf_queue: Option<String>

Which queue, if any, to specify when submitting normal jobs to LSF.

This may be superseded by short_task_lsf_queue, gpu_lsf_queue, or fpga_lsf_queue for corresponding tasks.

short_task_lsf_queue: Option<String>

Which queue, if any, to specify when submitting short tasks to LSF.

This may be superseded by gpu_lsf_queue or fpga_lsf_queue for tasks which require specialized hardware.

gpu_lsf_queue: Option<String>

Which queue, if any, to specify when submitting tasks which require a GPU to LSF.

fpga_lsf_queue: Option<String>

Which queue, if any, to specify when submitting tasks which require a GPU to LSF.

extra_bsub_args: Option<Vec<String>>

Additional command-line arguments to pass to bsub when submitting jobs to LSF.

max_scatter_concurrency: u64

The maximum number of scatter subtasks that can be evaluated concurrently.

By default, this is 200.

extra_apptainer_exec_args: Option<Vec<String>>

Additional command-line arguments to pass to apptainer exec when executing tasks.

apptainer_images_dir: PathBuf

The directory in which temporary directories will be created containing Apptainer .sif files.

This should be a location that is accessible by all jobs on the LSF cluster.

By default, this is $HOME/.cache/sprocket-apptainer-images, or /tmp/sprocket-apptainer-images if the home directory cannot be determined.

Implementations

Source

impl LsfApptainerBackendConfig

pub async fn validate(&self, engine_config: &Config) -> Result<(), Error>

Validate that the backend is appropriately configured.