Struct TaskInputs

pub struct TaskInputs { /* private fields */ }
Represents inputs to a task.

Implementations

Source

impl TaskInputs

pub fn iter(&self) -> impl Iterator<Item = (&str, &Value)> + use<'_>

Iterates the inputs to the task.

pub fn get(&self, name: &str) -> Option<&Value>

Gets an input by name.

pub fn set( &mut self, name: impl Into<String>, value: impl Into<Value>, ) -> Option<Value>

Sets a task input.

Returns the previous value, if any.

pub fn requirement(&self, name: &str) -> Option<&Value>

Gets an overridden requirement by name.

pub fn override_requirement( &mut self, name: impl Into<String>, value: impl Into<Value>, )

Overrides a requirement by name.

pub fn hint(&self, name: &str) -> Option<&Value>

Gets an overridden hint by name.

pub fn override_hint( &mut self, name: impl Into<String>, value: impl Into<Value>, )

Overrides a hint by name.

pub fn join_paths<'a>( &mut self, task: &Task, path: impl Fn(&str) -> Result<&'a Path>, ) -> Result<()>

Replaces any File or Directory input values with joining the specified path with the value.

This method will attempt to coerce matching input values to their expected types.

pub fn validate( &self, document: &Document, task: &Task, specified: Option<&HashSet<String>>, ) -> Result<()>

Validates the inputs for the given task.

The specified set of inputs are those that are present, but may not have values available at validation.