Struct WorkflowInputs

pub struct WorkflowInputs { /* private fields */ }
Represents inputs to a workflow.

Implementations

Source

impl WorkflowInputs

pub fn iter(&self) -> impl Iterator<Item = (&str, &Value)> + use<'_>

Iterates the inputs to the workflow.

pub fn get(&self, name: &str) -> Option<&Value>

Gets an input by name.

pub fn calls(&self) -> &HashMap<String, Inputs>

Gets the nested call inputs.

pub fn calls_mut(&mut self) -> &mut HashMap<String, Inputs>

Gets the nested call inputs.

pub fn set( &mut self, name: impl Into<String>, value: impl Into<Value>, ) -> Option<Value>

Sets a workflow input.

Returns the previous value, if any.

pub fn contains(&self, name: &str) -> bool

Checks if the inputs contain a value with the specified name.

This does not check nested call inputs.

pub fn join_paths<'a>( &mut self, workflow: &Workflow, path: impl Fn(&str) -> Result<&'a Path>, ) -> Result<()>

Replaces any File or Directory input values with joining the specified path with the value.

This method will attempt to coerce matching input values to their expected types.

pub fn validate( &self, document: &Document, workflow: &Workflow, specified: Option<&HashSet<String>>, ) -> Result<()>

Validates the inputs for the given workflow.

The specified set of inputs are those that are present, but may not have values available at validation.